@@ -20,14 +20,13 @@
 HomescreenModel::HomescreenModel(QObject *parent) :
     QStringListModel(QStringList()
                      << tr("All stations")
+                     << tr("Stations by genre")
+                     << tr("Stations by country")
+                     << tr("Stations by language")
                      << tr("Recently played stations")
                      << tr("Favourite stations")
-#ifdef TUNE_IN
-                     << tr("Podcasts")
-                     << tr("TuneIn"), parent)
-#else
-                     << tr("Podcasts"), parent)
-#endif
+                     << tr("My stations"),
+                     parent)
 {
     m_roleNames[Qt::DisplayRole] = "name";
 #if QT_VERSION < 0x050000
